@@ -240,8 +240,8 @@ except ImportError:
 try:
     from enum import Enum
     from azure.mgmt.core.tools import parse_resource_id, resource_id, is_valid_resource_id
-    from azure.cli.core import cloud as azure_cloud
     from azure.mgmt.network import NetworkManagementClient
+    from azure.mgmt.network import models as NetworkModels
     from azure.mgmt.resource.resources import ResourceManagementClient
     from azure.mgmt.managementgroups import ManagementGroupsAPI as ManagementGroupsClient
     from azure.mgmt.resource.subscriptions import SubscriptionClient
@@ -260,8 +260,9 @@ try:
     from azure.mgmt.sql import SqlManagementClient
     from azure.mgmt.servicebus import ServiceBusManagementClient
     from azure.mgmt.rdbms.postgresql import PostgreSQLManagementClient
-    from azure.mgmt.rdbms.postgresql_flexibleservers import PostgreSQLManagementClient as PostgreSQLFlexibleManagementClient
+    from azure.mgmt.postgresqlflexibleservers import PostgreSQLManagementClient as PostgreSQLFlexibleManagementClient
     from azure.mgmt.rdbms.mysql import MySQLManagementClient
+    from azure.mgmt.mysqlflexibleservers import MySQLManagementClient as MySQLFlexibleManagementClient
     from azure.mgmt.rdbms.mariadb import MariaDBManagementClient
     from azure.mgmt.containerregistry import ContainerRegistryManagementClient
     from azure.mgmt.containerinstance import ContainerInstanceManagementClient
@@ -279,15 +280,19 @@ try:
     except ImportError:
         import azure.mgmt.recoveryservicesbackup.activestamp.models as RecoveryServicesBackupModels
     from azure.mgmt.search import SearchManagementClient
-    from azure.mgmt.datalake.store import DataLakeStoreAccountManagementClient
-    import azure.mgmt.datalake.store.models as DataLakeStoreAccountModel
     from azure.mgmt.notificationhubs import NotificationHubsManagementClient
     from azure.mgmt.eventhub import EventHubManagementClient
     from azure.mgmt.datafactory import DataFactoryManagementClient
     import azure.mgmt.datafactory.models as DataFactoryModel
     from azure.identity._credentials import client_secret, user_password, certificate, managed_identity
     from azure.identity import AzureCliCredential
-    from msgraph import GraphServiceClient
+    from kiota_authentication_azure.azure_identity_authentication_provider import AzureIdentityAuthenticationProvider
+    from msgraph_core import GraphClientFactory, NationalClouds
+    from msgraph import GraphRequestAdapter, GraphServiceClient
+    from azure.mgmt.batch import BatchManagementClient
+    from azure.mgmt.batch import models as BatchManagementModel
+    from azure.mgmt.resourcehealth import ResourceHealthMgmtClient
+    from azure.mgmt.cdn import CdnManagementClient
 
 except ImportError as exc:
     Authentication = object
@@ -298,6 +303,7 @@ from base64 import b64encode, b64decode
 from hashlib import sha256
 from hmac import HMAC
 from time import time
+import subprocess
 
 try:
     from urllib import (urlencode, quote_plus)
@@ -306,8 +312,7 @@ except ImportError:
 
 try:
     from azure.cli.core.util import CLIError
-    from azure.common.credentials import get_cli_profile
-    from azure.common.cloud import get_cli_active_cloud
+    from azure.cli.core import cloud as azure_cloud
 except ImportError:
     HAS_AZURE_CLI_CORE = False
     HAS_AZURE_CLI_CORE_EXC = None
@@ -353,7 +358,7 @@ AZURE_PKG_VERSIONS = {
     },
     'NetworkManagementClient': {
         'package_name': 'network',
-        'expected_version': '2.3.0'
+        'expected_version': '26.0.0'
     },
     'ResourceManagementClient': {
         'package_name': 'resource',
@@ -389,7 +394,8 @@ class AzureRMModuleBase(object):
     def __init__(self, derived_arg_spec, bypass_checks=False, no_log=False,
                  check_invalid_arguments=None, mutually_exclusive=None, required_together=None,
                  required_one_of=None, add_file_common_args=False, supports_check_mode=False,
-                 required_if=None, supports_tags=True, facts_module=False, skip_exec=False, is_ad_resource=False):
+                 required_if=None, supports_tags=True, facts_module=False, skip_exec=False,
+                 is_ad_resource=False, required_by=None):
 
         merged_arg_spec = dict()
         merged_arg_spec.update(AZURE_COMMON_ARGS)
@@ -403,6 +409,9 @@ class AzureRMModuleBase(object):
         if required_if:
             merged_required_if += required_if
 
+        if not required_by:
+            required_by = dict()
+
         self.module = AnsibleModule(argument_spec=merged_arg_spec,
                                     bypass_checks=bypass_checks,
                                     no_log=no_log,
@@ -411,7 +420,8 @@ class AzureRMModuleBase(object):
                                     required_one_of=required_one_of,
                                     add_file_common_args=add_file_common_args,
                                     supports_check_mode=supports_check_mode,
-                                    required_if=merged_required_if)
+                                    required_if=merged_required_if,
+                                    required_by=required_by)
 
         if not HAS_PACKAGING_VERSION:
             self.fail(msg=missing_required_lib('packaging'),
@@ -428,6 +438,10 @@ class AzureRMModuleBase(object):
         self._management_group_client = None
         self._resource_client = None
         self._compute_client = None
+        self._disk_client = None
+        self._image_version_client = None
+        self._multi_disk_client = None
+        self._diskencryptionset_client = None
         self._image_client = None
         self._dns_client = None
         self._private_dns_client = None
@@ -435,10 +449,12 @@ class AzureRMModuleBase(object):
         self._marketplace_client = None
         self._sql_client = None
         self._mysql_client = None
+        self._mysql_flexible_client = None
         self._mariadb_client = None
         self._postgresql_client = None
         self._postgresql_flexible_client = None
         self._containerregistry_client = None
+        self._containerregistrytoken_client = None
         self._containerinstance_client = None
         self._containerservice_client = None
         self._managedcluster_client = None
@@ -446,6 +462,10 @@ class AzureRMModuleBase(object):
         self._monitor_autoscale_settings_client = None
         self._monitor_log_profiles_client = None
         self._monitor_diagnostic_settings_client = None
+        self._monitor_data_collection_rules_client = None
+        self._monitor_management_client_action_groups = None
+        self._monitor_management_client_activity_log_alerts = None
+        self._monitor_management_client_metric_alerts = None
         self._resource = None
         self._log_analytics_client = None
         self._servicebus_client = None
@@ -458,6 +478,9 @@ class AzureRMModuleBase(object):
         self._datafactory_client = None
         self._notification_hub_client = None
         self._event_hub_client = None
+        self._batch_account_client = None
+        self._resourcehealth_client = None
+        self._cdn_client = None
 
         self.check_mode = self.module.check_mode
         self.api_profile = self.module.params.get('api_profile')
@@ -608,7 +631,10 @@ class AzureRMModuleBase(object):
         '''
         resource_dict = parse_resource_id(resource) if not isinstance(resource, dict) else resource
         resource_dict['resource_group'] = resource_dict.get('resource_group', self.resource_group)
-        resource_dict['subscription_id'] = resource_dict.get('subscription_id', self.subscription_id)
+        if 'subscription_id' in resource_dict:
+            resource_dict['subscription_id'] = resource_dict['subscription_id']
+        else:
+            resource_dict['subscription_id'] = resource_dict.get('subscription', self.subscription_id)
         return resource_dict
 
     def serialize_obj(self, obj, class_name, enum_modules=None):
@@ -702,8 +728,14 @@ class AzureRMModuleBase(object):
         try:
             self.log("Getting storage account detail")
             account = self.storage_client.storage_accounts.get_properties(resource_group_name=resource_group_name, account_name=storage_account_name)
-            if auth_mode == 'login' and self.azure_auth.credentials.get('credential'):
-                credential = self.azure_auth.credentials['credential']
+            if auth_mode == 'login' and self.azure_auth.credentials.get('credentials'):
+                credential = self.azure_auth.credentials['credentials']
+            elif (auth_mode == 'login' and self.azure_auth.credentials.get('tenant')
+                  and self.azure_auth.credentials.get('client_id')
+                  and self.azure_auth.credentials.get('secret')):
+                credential = client_secret.ClientSecretCredential(tenant_id=self.azure_auth.credentials.get('tenant'),
+                                                                  client_id=self.azure_auth.credentials.get('client_id'),
+                                                                  client_secret=self.azure_auth.credentials.get('secret'))
             else:
                 account_keys = self.storage_client.storage_accounts.list_keys(resource_group_name=resource_group_name, account_name=storage_account_name)
                 credential = account_keys.keys[0].value
@@ -889,7 +921,16 @@ class AzureRMModuleBase(object):
     #    return client
 
     def get_msgraph_client(self):
-        return GraphServiceClient(self.azure_auth.azure_credential_track2)
+        auth_provider = AzureIdentityAuthenticationProvider(self.azure_auth.azure_credential_track2)
+        cloud_mapping = {
+            azure_cloud.AZURE_CHINA_CLOUD: NationalClouds.China,
+            azure_cloud.AZURE_US_GOV_CLOUD: NationalClouds.US_GOV,
+            azure_cloud.AZURE_GERMAN_CLOUD: NationalClouds.Germany
+        }
+        host = cloud_mapping.get(self._cloud_environment, NationalClouds.Global)
+        client = GraphClientFactory.create_with_default_middleware(host=host)
+        request_adapter = GraphRequestAdapter(auth_provider, client=client)
+        return GraphServiceClient(self.azure_auth.azure_credential_track2, request_adapter=request_adapter)
 
     def get_mgmt_svc_client(self, client_type, base_url=None, api_version=None, suppress_subscription_id=False):
         self.log('Getting management service client {0}'.format(client_type.__name__))
@@ -947,9 +988,17 @@ class AzureRMModuleBase(object):
             def _ansible_get_models(self, *arg, **kwarg):
                 return self._ansible_models
 
-            setattr(client, '_ansible_models', importlib.import_module(client_type.__module__).models)
+            try:
+                setattr(client, '_ansible_models', importlib.import_module(client_type.__module__).models)
+            except AttributeError:
+                if hasattr(importlib.import_module(client_type.__module__), '_modeles'):
+                    setattr(client, '_ansible_models', importlib.import_module(client_type.__module__)._models)
+                else:
+                    pass
             client.models = types.MethodType(_ansible_get_models, client)
 
+        client._config.user_agent_policy = self.add_user_agent(client._config.user_agent_policy)
+
         if self.azure_auth._cert_validation_mode == 'ignore':
             client._config.session_configuration_callback = self._validation_ignore_callback
 
@@ -1011,12 +1060,12 @@ class AzureRMModuleBase(object):
         if not self._storage_client:
             self._storage_client = self.get_mgmt_svc_client(StorageManagementClient,
                                                             base_url=self._cloud_environment.endpoints.resource_manager,
-                                                            api_version='2021-06-01')
+                                                            api_version='2023-05-01')
         return self._storage_client
 
     @property
     def storage_models(self):
-        return StorageManagementClient.models("2021-06-01")
+        return StorageManagementClient.models("2023-05-01")
 
     @property
     def authorization_client(self):
@@ -1038,12 +1087,12 @@ class AzureRMModuleBase(object):
             self._subscription_client = self.get_mgmt_svc_client(SubscriptionClient,
                                                                  base_url=self._cloud_environment.endpoints.resource_manager,
                                                                  suppress_subscription_id=True,
-                                                                 api_version='2019-11-01')
+                                                                 api_version='2022-12-01')
         return self._subscription_client
 
     @property
     def subscription_models(self):
-        return SubscriptionClient.models("2019-11-01")
+        return SubscriptionClient.models("2022-12-01")
 
     @property
     def management_groups_client(self):
@@ -1061,13 +1110,13 @@ class AzureRMModuleBase(object):
         if not self._network_client:
             self._network_client = self.get_mgmt_svc_client(NetworkManagementClient,
                                                             base_url=self._cloud_environment.endpoints.resource_manager,
-                                                            api_version='2021-03-01')
+                                                            api_version='2024-01-01')
         return self._network_client
 
     @property
     def network_models(self):
         self.log("Getting network models...")
-        return NetworkManagementClient.models("2021-03-01")
+        return NetworkModels
 
     @property
     def rm_client(self):
@@ -1075,13 +1124,13 @@ class AzureRMModuleBase(object):
         if not self._resource_client:
             self._resource_client = self.get_mgmt_svc_client(ResourceManagementClient,
                                                              base_url=self._cloud_environment.endpoints.resource_manager,
-                                                             api_version='2019-10-01')
+                                                             api_version='2022-09-01')
         return self._resource_client
 
     @property
     def rm_models(self):
         self.log("Getting resource manager models")
-        return ResourceManagementClient.models("2019-10-01")
+        return ResourceManagementClient.models("2022-09-01")
 
     @property
     def image_client(self):
@@ -1089,13 +1138,13 @@ class AzureRMModuleBase(object):
         if not self._image_client:
             self._image_client = self.get_mgmt_svc_client(ComputeManagementClient,
                                                           base_url=self._cloud_environment.endpoints.resource_manager,
-                                                          api_version='2021-04-01')
+                                                          api_version='2024-07-01')
         return self._image_client
 
     @property
     def image_models(self):
         self.log("Getting compute image models")
-        return ComputeManagementClient.models("2021-04-01")
+        return ComputeManagementClient.models("2024-07-01")
 
     @property
     def compute_client(self):
@@ -1103,27 +1152,84 @@ class AzureRMModuleBase(object):
         if not self._compute_client:
             self._compute_client = self.get_mgmt_svc_client(ComputeManagementClient,
                                                             base_url=self._cloud_environment.endpoints.resource_manager,
-                                                            api_version='2021-04-01')
+                                                            api_version='2024-07-01')
         return self._compute_client
 
     @property
     def compute_models(self):
         self.log("Getting compute models")
+        return ComputeManagementClient.models("2024-07-01")
+
+    @property
+    def disk_client(self):
+        self.log('Getting disk client')
+        if not self._disk_client:
+            self._disk_client = self.get_mgmt_svc_client(ComputeManagementClient,
+                                                         base_url=self._cloud_environment.endpoints.resource_manager,
+                                                         api_version='2023-04-02')
+        return self._disk_client
+
+    @property
+    def disk_models(self):
+        self.log("Getting disk models")
+        return ComputeManagementClient.models("2023-04-02")
+
+    @property
+    def image_version_client(self):
+        self.log('Getting gallery image version client')
+        if not self._image_version_client:
+            self._image_version_client = self.get_mgmt_svc_client(ComputeManagementClient,
+                                                                  base_url=self._cloud_environment.endpoints.resource_manager,
+                                                                  api_version='2023-07-03')
+        return self._image_version_client
+
+    @property
+    def image_version_models(self):
+        self.log("Getting image version models")
+        return ComputeManagementClient.models("2023-07-03")
+
+    @property
+    def multi_disk_client(self):
+        self.log('Getting disk client')
+        if not self._multi_disk_client:
+            self._multi_disk_client = self.get_mgmt_svc_client(ComputeManagementClient,
+                                                               base_url=self._cloud_environment.endpoints.resource_manager,
+                                                               api_version='2021-04-01')
+        return self._multi_disk_client
+
+    @property
+    def multi_disk_models(self):
+        self.log("Getting disk models")
         return ComputeManagementClient.models("2021-04-01")
 
+    @property
+    def diskencryptionset_client(self):
+        self.log('Getting diskencryptionset client')
+        base_url = self._cloud_environment.endpoints.resource_manager
+        if not self._diskencryptionset_client:
+            self._diskencryptionset_client = self.get_mgmt_svc_client(ComputeManagementClient,
+                                                                      base_url=base_url,
+                                                                      api_version='2024-03-02')
+        return self._diskencryptionset_client
+
+    @property
+    def diskencryptionset_models(self):
+        self.log("Getting compute models")
+        return ComputeManagementClient.models("2024-03-02")
+
     @property
     def dns_client(self):
         self.log('Getting dns client')
         if not self._dns_client:
             self._dns_client = self.get_mgmt_svc_client(DnsManagementClient,
                                                         base_url=self._cloud_environment.endpoints.resource_manager,
-                                                        api_version='2018-05-01')
+                                                        api_version='2023-07-01-preview')
         return self._dns_client
 
     @property
     def dns_models(self):
         self.log("Getting dns models...")
-        return DnsManagementClient.models('2018-05-01')
+        return DnsManagementClient.models('2023-07-01-preview')
 
     @property
     def private_dns_client(self):
@@ -1145,7 +1251,7 @@ class AzureRMModuleBase(object):
         if not self._web_client:
             self._web_client = self.get_mgmt_svc_client(WebSiteManagementClient,
                                                         base_url=self._cloud_environment.endpoints.resource_manager,
-                                                        api_version='2021-03-01')
+                                                        api_version='2023-12-01')
         return self._web_client
 
     @property
@@ -1154,13 +1260,13 @@ class AzureRMModuleBase(object):
         if not self._containerservice_client:
             self._containerservice_client = self.get_mgmt_svc_client(ContainerServiceClient,
                                                                      base_url=self._cloud_environment.endpoints.resource_manager,
-                                                                     api_version='2017-07-01')
+                                                                     api_version='2019-04-01')
         return self._containerservice_client
 
     @property
     def managedcluster_models(self):
         self.log("Getting container service models")
-        return ContainerServiceClient.models('2022-02-01')
+        return ContainerServiceClient.models('2024-08-01')
 
     @property
     def managedcluster_client(self):
@@ -1168,7 +1274,7 @@ class AzureRMModuleBase(object):
         if not self._managedcluster_client:
             self._managedcluster_client = self.get_mgmt_svc_client(ContainerServiceClient,
                                                                    base_url=self._cloud_environment.endpoints.resource_manager,
-                                                                   api_version='2022-02-01')
+                                                                   api_version='2024-08-01')
         return self._managedcluster_client
 
     @property
@@ -1184,7 +1290,8 @@ class AzureRMModuleBase(object):
         self.log('Getting PostgreSQL client')
         if not self._postgresql_flexible_client:
             self._postgresql_flexible_client = self.get_mgmt_svc_client(PostgreSQLFlexibleManagementClient,
-                                                                        base_url=self._cloud_environment.endpoints.resource_manager)
+                                                                        base_url=self._cloud_environment.endpoints.resource_manager,
+                                                                        api_version='2024-08-01')
         return self._postgresql_flexible_client
 
     @property
@@ -1195,6 +1302,15 @@ class AzureRMModuleBase(object):
                                                                base_url=self._cloud_environment.endpoints.resource_manager)
         return self._postgresql_client
 
+    @property
+    def mysql_flexible_client(self):
+        self.log('Getting MySQL Flexible client')
+        if not self._mysql_flexible_client:
+            self._mysql_flexible_client = self.get_mgmt_svc_client(MySQLFlexibleManagementClient,
+                                                                   base_url=self._cloud_environment.endpoints.resource_manager,
+                                                                   api_version='2024-08-01')
+        return self._mysql_flexible_client
+
     @property
     def mysql_client(self):
         self.log('Getting MySQL client')
@@ -1221,13 +1337,23 @@ class AzureRMModuleBase(object):
 
         return self._containerregistry_client
 
+    @property
+    def containerregistrytoken_client(self):
+        self.log('Getting container registry token mgmt client')
+        if not self._containerregistrytoken_client:
+            self._containerregistrytoken_client = self.get_mgmt_svc_client(ContainerRegistryManagementClient,
+                                                                           base_url=self._cloud_environment.endpoints.resource_manager,
+                                                                           api_version='2023-07-01')
+
+        return self._containerregistrytoken_client
+
     @property
     def containerinstance_client(self):
         self.log('Getting container instance mgmt client')
         if not self._containerinstance_client:
             self._containerinstance_client = self.get_mgmt_svc_client(ContainerInstanceManagementClient,
                                                                       base_url=self._cloud_environment.endpoints.resource_manager,
-                                                                      api_version='2018-06-01')
+                                                                      api_version='2023-05-01')
 
         return self._containerinstance_client
 
@@ -1253,7 +1379,7 @@ class AzureRMModuleBase(object):
         if not self._monitor_autoscale_settings_client:
             self._monitor_autoscale_settings_client = self.get_mgmt_svc_client(MonitorManagementClient,
                                                                                base_url=self._cloud_environment.endpoints.resource_manager,
-                                                                               api_version="2015-04-01")
+                                                                               api_version="2022-10-01")
         return self._monitor_autoscale_settings_client
 
     @property
@@ -1274,6 +1400,42 @@ class AzureRMModuleBase(object):
                                                                                 api_version="2021-05-01-preview")
         return self._monitor_diagnostic_settings_client
 
+    @property
+    def monitor_management_client_action_groups(self):
+        self.log('Getting monitor client for diagnostic_settings')
+        if not self._monitor_management_client_action_groups:
+            self._monitor_management_client_action_groups = self.get_mgmt_svc_client(MonitorManagementClient,
+                                                                                     base_url=self._cloud_environment.endpoints.resource_manager,
+                                                                                     api_version='2023-01-01')
+        return self._monitor_management_client_action_groups
+
+    @property
+    def monitor_management_client_activity_log_alerts(self):
+        self.log('Getting monitor client for diagnostic_settings')
+        if not self._monitor_management_client_activity_log_alerts:
+            self._monitor_management_client_activity_log_alerts = self.get_mgmt_svc_client(MonitorManagementClient,
+                                                                                           base_url=self._cloud_environment.endpoints.resource_manager,
+                                                                                           api_version='2020-10-01')
+        return self._monitor_management_client_activity_log_alerts
+
+    @property
+    def monitor_management_client_data_collection_rules(self):
+        self.log('Getting monitor client for diagnostic_settings')
+        if not self._monitor_data_collection_rules_client:
+            self._monitor_data_collection_rules_client = self.get_mgmt_svc_client(MonitorManagementClient,
+                                                                                  base_url=self._cloud_environment.endpoints.resource_manager,
+                                                                                  api_version='2022-06-01')
+        return self._monitor_data_collection_rules_client
+
+    @property
+    def monitor_management_client_metric_alerts(self):
+        self.log('Getting monitor client for diagnostic_settings')
+        if not self._monitor_management_client_metric_alerts:
+            self._monitor_management_client_metric_alerts = self.get_mgmt_svc_client(MonitorManagementClient,
+                                                                                     base_url=self._cloud_environment.endpoints.resource_manager,
+                                                                                     api_version='2018-03-01')
+        return self._monitor_management_client_metric_alerts
+
     @property
     def log_analytics_client(self):
         self.log('Getting log analytics client')
@@ -1292,13 +1454,13 @@ class AzureRMModuleBase(object):
         self.log('Getting servicebus client')
         if not self._servicebus_client:
             self._servicebus_client = self.get_mgmt_svc_client(ServiceBusManagementClient,
-                                                               api_version="2021-06-01-preview",
+                                                               api_version="2022-10-01-preview",
                                                                base_url=self._cloud_environment.endpoints.resource_manager)
         return self._servicebus_client
 
     @property
     def servicebus_models(self):
-        return ServiceBusManagementClient.models("2021-06-01-preview")
+        return ServiceBusManagementClient.models("2022-10-01-preview")
 
     @property
     def automation_client(self):
@@ -1317,7 +1479,7 @@ class AzureRMModuleBase(object):
         self.log('Getting iothub client')
         if not self._IoThub_client:
             self._IoThub_client = self.get_mgmt_svc_client(IotHubClient,
-                                                           api_version='2018-04-01',
+                                                           api_version='2023-06-30-preview',
                                                            base_url=self._cloud_environment.endpoints.resource_manager)
         return self._IoThub_client
 
@@ -1357,22 +1519,9 @@ class AzureRMModuleBase(object):
         if not self._search_client:
             self._search_client = self.get_mgmt_svc_client(SearchManagementClient,
                                                            base_url=self._cloud_environment.endpoints.resource_manager,
-                                                           api_version='2020-08-01')
+                                                           api_version='2024-06-01-preview')
         return self._search_client
 
-    @property
-    def datalake_store_client(self):
-        self.log('Getting datalake store client...')
-        if not self._datalake_store_client:
-            self._datalake_store_client = self.get_mgmt_svc_client(DataLakeStoreAccountManagementClient,
-                                                                   base_url=self._cloud_environment.endpoints.resource_manager,
-                                                                   api_version='2016-11-01')
-        return self._datalake_store_client
-
-    @property
-    def datalake_store_models(self):
-        return DataLakeStoreAccountModel
-
     @property
     def notification_hub_client(self):
         self.log('Getting notification hub client')
@@ -1380,7 +1529,7 @@ class AzureRMModuleBase(object):
             self._notification_hub_client = self.get_mgmt_svc_client(
                 NotificationHubsManagementClient,
                 base_url=self._cloud_environment.endpoints.resource_manager,
-                api_version='2016-03-01')
+                api_version='2023-09-01')
         return self._notification_hub_client
 
     @property
@@ -1390,7 +1539,7 @@ class AzureRMModuleBase(object):
             self._event_hub_client = self.get_mgmt_svc_client(
                 EventHubManagementClient,
                 base_url=self._cloud_environment.endpoints.resource_manager,
-                api_version='2021-11-01')
+                api_version='2024-01-01')
         return self._event_hub_client
 
     @property
@@ -1405,6 +1554,35 @@ class AzureRMModuleBase(object):
     def datafactory_model(self):
         return DataFactoryModel
 
+    @property
+    def batch_account_client(self):
+        self.log('Getting batch account client...')
+        if not self._batch_account_client:
+            self._batch_account_client = self.get_mgmt_svc_client(BatchManagementClient,
+                                                                  base_url=self._cloud_environment.endpoints.resource_manager)
+        return self._batch_account_client
+
+    @property
+    def resourcehealth_client(self):
+        self.log('Getting resource health client...')
+        if not self._resourcehealth_client:
+            self._resourcehealth_client = self.get_mgmt_svc_client(ResourceHealthMgmtClient,
+                                                                   base_url=self._cloud_environment.endpoints.resource_manager)
+        return self._resourcehealth_client
+
+    @property
+    def batch_account_model(self):
+        return BatchManagementModel
+
+    @property
+    def cdn_client(self):
+        self.log('Getting cdn client...')
+        if not self._cdn_client:
+            self._cdn_client = self.get_mgmt_svc_client(CdnManagementClient,
+                                                        base_url=self._cloud_environment.endpoints.resource_manager,
+                                                        api_version='2024-02-01')
+        return self._cdn_client
+
 
 class AzureRMAuthException(Exception):
     pass
@@ -1489,10 +1667,10 @@ class AzureRMAuth(object):
                 except Exception as e:
                     self.fail("cloud_environment {0} could not be resolved: {1}".format(raw_cloud_env, e.message), exception=traceback.format_exc())
 
-        if self.credentials.get('subscription_id', None) is None and self.credentials.get('credentials') is None:
+        if self.credentials.get('subscription_id', None) is None and not self.is_ad_resource:
             self.fail("Credentials did not include a subscription_id value.")
         self.log("setting subscription_id")
-        self.subscription_id = self.credentials['subscription_id']
+        self.subscription_id = self.credentials.get('subscription_id')
 
         # get authentication authority
         # for adfs, user could pass in authority or not.
@@ -1580,11 +1758,11 @@ class AzureRMAuth(object):
             except Exception:
                 pass
 
-        if credentials.get('subscription_id'):
+        if credentials.get('subscription_id') is None and not self.is_ad_resource:
+            return None
+        else:
             return credentials
 
-        return None
-
     def _get_msi_credentials(self, subscription_id=None, client_id=None, _cloud_environment=None, **kwargs):
         # Get object `cloud_environment` from string `_cloud_environment`
         cloud_environment = None
@@ -1625,24 +1803,30 @@ class AzureRMAuth(object):
             'auth_source': 'msi'
         }
 
-    def _get_azure_cli_credentials(self, subscription_id=None, resource=None):
-        if self.is_ad_resource:
-            resource = 'https://graph.windows.net/'
+    def _get_azure_cli_credentials(self, subscription_id=None):
         subscription_id = subscription_id or self._get_env('subscription_id')
+        if not subscription_id:
+            try:
+                cmd = ["az", "account", "show", "--query", "id"]
+                subscription_id = subprocess.run(cmd, capture_output=True, text=True, check=True).stdout.strip().strip('"')
+            except Exception as ec:
+                raise CLIError("Obtain the az login's subscription occurred exception as {0}".format(ec))
+
         try:
-            profile = get_cli_profile()
-        except Exception as exc:
-            self.fail("Failed to load CLI profile {0}.".format(str(exc)))
+            cmd = ["az", "cloud", "show", "--query", "name"]
+            cloud_name = subprocess.run(cmd, capture_output=True, text=True, check=True).stdout.strip().strip('"')
+            all_clouds = [x[1] for x in inspect.getmembers(azure_cloud) if isinstance(x[1], azure_cloud.Cloud)]
+            matched_clouds = [x for x in all_clouds if x.name == cloud_name]
+        except Exception as ec:
+            raise CLIError("Obtain the az login's active cloud occurred exception as {0}".format(ec))
 
-        cred, subscription_id, tenant = profile.get_login_credentials(
-            subscription_id=subscription_id)
-        cloud_environment = get_cli_active_cloud()
+        if len(matched_clouds) != 1:
+            raise CLIError("Obtain the active cloud failed, There is no or multiple matching clouds")
 
-        az_cli = AzureCliCredential()
         cli_credentials = {
-            'credentials': az_cli if self.is_ad_resource else cred,
+            'credentials': AzureCliCredential(),
             'subscription_id': subscription_id,
-            'cloud_environment': cloud_environment
+            'cloud_environment': matched_clouds[0],
         }
         return cli_credentials
 
@@ -1655,11 +1839,11 @@ class AzureRMAuth(object):
             credentials = self._get_profile(env_credentials['profile'])
             return credentials
 
-        if env_credentials.get('subscription_id') is not None:
+        if env_credentials.get('subscription_id') is None and not self.is_ad_resource:
+            return None
+        else:
             return env_credentials
 
-        return None
-
     def _get_credentials(self, auth_source=None, **params):
         # Get authentication credentials.
         self.log('Getting credentials')
