@@ -1,13 +1,21 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: network_device_interface_poe_info
-short_description: Information module for Network Device Interface Poe Info
+short_description: Information module for Network Device
+  Interface Poe
 description:
-  - This module represents an alias of the module network_device_interface_poe_v1_info
+  - Get all Network Device Interface Poe. - > Returns
+    POE interface details for the device, where deviceuuid
+    is mandatory & accepts comma seperated interface
+    names which is optional and returns information
+    for that particular interfaces where operStatus
+    = operationalStatus .
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -22,24 +30,28 @@ options:
     type: str
   interfaceNameList:
     description:
-      - InterfaceNameList query parameter. Comma seperated interface names.
+      - InterfaceNameList query parameter. Comma seperated
+        interface names.
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Devices ReturnsPOEInterfaceDetailsForTheDeviceV1
-    description: Complete reference of the ReturnsPOEInterfaceDetailsForTheDeviceV1
+  - name: Cisco DNA Center documentation for Devices
+      ReturnsPOEInterfaceDetailsForTheDevice
+    description: Complete reference of the ReturnsPOEInterfaceDetailsForTheDevice
       API.
-    link:
-      https://developer.cisco.com/docs/dna-center/#!returns-poe-interface-details-for-the-device
+    link: https://developer.cisco.com/docs/dna-center/#!returns-poe-interface-details-for-the-device
 notes:
-  - SDK Method used are devices.Devices.poe_interface_details,
-  - Paths used are get /dna/intent/api/v1/network-device/{deviceUuid}/interface/poe-detail,
-  - It should be noted that this module is an alias of network_device_interface_poe_v1_info
+  - SDK Method used are
+    devices.Devices.poe_interface_details,
+  - Paths used are
+    get /dna/intent/api/v1/network-device/{deviceUuid}/interface/poe-detail,
 """
+
 EXAMPLES = r"""
-- name: Get all Network Device Interface Poe Info
+---
+- name: Get all Network Device Interface Poe
   cisco.dnac.network_device_interface_poe_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
