@@ -136,7 +136,7 @@ from ansible_collections.community.vmware.plugins.module_utils.vmware import (
     find_datacenter_by_name,
     wait_for_task)
 from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 
 
 class VMwareCluster(PyVmomi):
