@@ -397,8 +397,9 @@ except ImportError:
         pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, option_diff, vmware_argument_spec
-from ansible.module_utils._text import to_native
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, option_diff
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
+from ansible.module_utils.common.text.converters import to_native
 
 
 class VmwareVcenterSettings(PyVmomi):
@@ -858,7 +859,7 @@ class VmwareVcenterSettings(PyVmomi):
 
 def main():
     """Main"""
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         database=dict(
             type='dict',
